@@ -85,7 +85,7 @@ class Solution(SolutionInterface):
         return new_solution
 
     def __hash__(self):
-        return hash(str(self.values))
+        return hash(str(set(self.values)))
 
     def toDict(self):
         d = {'values': self.values,
@@ -128,34 +128,35 @@ class AbstractEA(ABC):
         return self.final_population
 
     def __signalHandler(self, signum, frame):
-        print("Dumping current population.")
-        try:
-            pop = self._get_current_population()
-            data = [s.toDict() for s in pop]
-            import json
-            from datetime import datetime
-            now = datetime.now()
-            dt_string = now.strftime("%d%m%Y-%H%M%S")
-            with open(f'mewpy-dump-{dt_string}.json', 'w') as outfile:
-                json.dump(data, outfile)
-        except Exception:
-            print("Unable to dump population.")
-        print("Exiting")
+        if EAConstants.KILL_DUMP:
+            print("Dumping current population.")
+            try:
+                pop = self._get_current_population()
+                data = [s.toDict() for s in pop]
+                import json
+                from datetime import datetime
+                now = datetime.now()
+                dt_string = now.strftime("%d%m%Y-%H%M%S")
+                with open(f'mewpy-dump-{dt_string}.json', 'w') as outfile:
+                    json.dump(data, outfile)
+            except Exception:
+                print("Unable to dump population.")
+            print("Exiting")
         sys.exit(0)
 
-    @abstractmethod
+    @ abstractmethod
     def _convertPopulation(self, population):
         raise NotImplementedError
 
-    @abstractmethod
+    @ abstractmethod
     def _run_so(self):
         raise NotImplementedError
 
-    @abstractmethod
+    @ abstractmethod
     def _run_mo(self):
         raise NotImplementedError
 
-    @abstractmethod
+    @ abstractmethod
     def _get_current_population(self):
         raise NotImplementedError
 
