@@ -1,4 +1,5 @@
 from enum import Enum
+
 from ..util.constants import ModelConstants
 
 solvers = []
@@ -94,7 +95,12 @@ default_solver = None
 map_model_simulator = {
     'geckopy.gecko.GeckoModel': ('mewpy.simulation.cobra', 'GeckoSimulation'),
     'mewpy.model.gecko.GeckoModel': ('mewpy.simulation.reframed', 'GeckoSimulation'),
-    'mewpy.model.smoment.SMomentModel': ('mewpy.simulation.reframed', 'GeckoSimulation')
+    'mewpy.model.smoment.SMomentModel': ('mewpy.simulation.reframed', 'GeckoSimulation'),
+    'mewpy.model.model.Model': ('mewpy.simulation.mew', 'Simulation'),
+    'mewpy.model.metabolic.MetabolicModel': ('mewpy.simulation.mew', 'Simulation'),
+    'mewpy.model.regulatory.RegulatoryModel': ('mewpy.simulation.mew', 'Simulation'),
+    'mewpy.model.model.MetabolicRegulatoryModel': ('mewpy.simulation.mew', 'Simulation'),
+    'mewpy.model.model.RegulatoryMetabolicModel': ('mewpy.simulation.mew', 'Simulation'),
 }
 
 
@@ -108,7 +114,9 @@ def get_simulator(model, envcond=None, constraints=None, reference=None, reset_s
 
     :param model: the model
     :param dict envcond: A dictionary of environmental conditions.
-    :param dict contrainsts: A dictionary of additional persistent constraints.
+    :param dict constraints: A dictionary of additional persistent constraints.
+    :param dict reference: A dictionary of the wild type flux values
+    :param bool reset_solver: Whether to reset the solver before each simulation
     :returns: An instance of Simulator
     """
 
@@ -147,6 +155,7 @@ def get_simulator(model, envcond=None, constraints=None, reference=None, reset_s
                         model, envcond=envcond, constraints=constraints, reference=reference, reset_solver=reset_solver)
             except ImportError:
                 pass
+
     if not instance:
         raise ValueError(f"The model <{name}> has no defined simulator.")
     return instance
@@ -161,6 +170,15 @@ def get_container(model):
     :returns: A container.
 
     """
+
+    from mewpy.model import Model, RegulatoryModel, MetabolicModel
+
+    if isinstance(model, (Model, MetabolicModel, RegulatoryModel)):
+
+        from .mew import MewModelContainer
+
+        return MewModelContainer(model)
+
     try:
         from reframed.core.cbmodel import CBModel
         if isinstance(model, CBModel):
